<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Demo
 */

function customizer_library_demo_options() {

	// Theme defaults
	$primary_color = '#2da6e9';
	$nav_bg_color = '#323946';
	$footer_bg_color = '#323946';

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// More Examples
	$section = 'examples';

	// Arrays

	$layout_choices = array(
		'choice-1' => 'Responsive Layout',
		'choice-2' => 'Fixed Layout'
	);

	$home_layout_choices = array(
		'choice-1' => 'Content + Sidebar',
		'choice-2' => 'Full Width Content'
	);

	$text_color_choices = array(
		'choice-1' => 'Light',
		'choice-2' => 'Dark'
	);

	$archive_style_choices = array(
		'choice-1' => 'Grid',
		'choice-2' => 'List'
	);

	$date_format_choices = array(
		'choice-1' => 'xx days ago',
		'choice-2' => 'WordPress Settings'
	);

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Theme Settings', 'videocloud-pro' ),
		'priority' => '10'
	);

	$options['logo'] = array(
		'id' => 'logo',
		'label'   => __( 'Logo', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => get_template_directory_uri().'/assets/img/logo.png'
	);

	$options['favicon'] = array(
		'id' => 'favicon',
		'label'   => __( 'Favicon', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => ''
	);

	$options['primary-color'] = array(
		'id' => 'primary-color',
		'label'   => __( 'Theme Primary Color', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $primary_color // hex
	);

	$options['nav-bg-color'] = array(
		'id' => 'nav-bg-color',
		'label'   => __( 'Navigation Menu Background Color', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $nav_bg_color // hex
	);

	$options['nav-text-color'] = array(
		'id' => 'nav-text-color',
		'label'   => __( 'Navigation Menu Text Color', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $text_color_choices,
		'default' => 'choice-1'
	);

	$options['footer-bg-color'] = array(
		'id' => 'footer-bg-color',
		'label'   => __( 'Footer Background Color', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $footer_bg_color // hex
	);

	$options['site-layout'] = array(
		'id' => 'site-layout',
		'label'   => __( 'Site Layout', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $layout_choices,
		'default' => 'choice-1'
	);

	$options['content-layout'] = array(
		'id' => 'content-layout',
		'label'   => __( 'Content Layout', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $home_layout_choices,
		'default' => 'choice-1'
	);

	$options['primary-font'] = array(
		'id' => 'primary-font',
		'label'   => __( 'Body Font', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Open Sans'
	);

	$options['secondary-font'] = array(
		'id' => 'secondary-font',
		'label'   => __( 'Heading Font', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Open Sans'
	);
	$options['sticky-nav-on'] = array(
		'id' => 'sticky-nav-on',
		'label'   => __( 'Sticky header navigation', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['header-social-on'] = array(
		'id' => 'header-social-on',
		'label'   => __( 'Display social icons on site header', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['header-search-on'] = array(
		'id' => 'header-search-on',
		'label'   => __( 'Display header search form', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['header-cart-on'] = array(
		'id' => 'header-cart-on',
		'label'   => __( 'Display cart menu on header', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['mobile-nav-heading'] = array(
		'id' => 'mobile-nav-heading',
		'label'   => __( 'Mobile Menu Heading Text', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Menu', 'videocloud-pro'),
	);

	$options['home-featured-on'] = array(
		'id' => 'home-featured-on',
		'label'   => __( 'Display featured content on homepage', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['featured-num'] = array(
		'id' => 'featured-num',
		'label'   => __( 'Number of featured posts', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '9',
	);

	$options['home-recent-on'] = array(
		'id' => 'home-recent-on',
		'label'   => __( 'Display recent content on homepage', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['recent-heading'] = array(
		'id' => 'recent-heading',
		'label'   => __( 'Recent content heading text', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Recent videos', 'videocloud-pro'),
	);

	$options['all-posts-url'] = array(
		'id' => 'all-posts-url',
		'label'   => __( 'Page URL to display latest posts', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'url',
		'default' => home_url() . '/latest',
	);

	$options['date-format'] = array(
		'id' => 'date-format',
		'label'   => __( 'Post date format', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $date_format_choices,
		'default' => 'choice-1'
	);

	$options['breadcrumbs-on'] = array(
		'id' => 'breadcrumbs-on',
		'label'   => __( 'Display breadcrumbs on single posts', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => false,
	);

	$options['single-share-on'] = array(
		'id' => 'single-share-on',
		'label'   => __( 'Display share icons on single posts', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['author-box-on'] = array(
		'id' => 'author-box-on',
		'label'   => __( 'Display author box on single posts', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);
	$options['related-posts-on'] = array(
		'id' => 'related-posts-on',
		'label'   => __( 'Display related posts on single posts', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['footer-widgets-on'] = array(
		'id' => 'footer-widgets-on',
		'label'   => __( 'Display footer widgets', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['back-top-on'] = array(
		'id' => 'back-top-on',
		'label'   => __( 'Display "back to top" icon link on the site bottom', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['facebook-url'] = array(
		'id' => 'facebook-url',
		'label'   => __( 'Your Facebook URL', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['twitter-url'] = array(
		'id' => 'twitter-url',
		'label'   => __( 'Your Twitter URL', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['youtube-url'] = array(
		'id' => 'youtube-url',
		'label'   => __( 'Your YouTube URL', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['linkedin-url'] = array(
		'id' => 'linkedin-url',
		'label'   => __( 'Your LinkedIn URL', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['pinterest-url'] = array(
		'id' => 'pinterest-url',
		'label'   => __( 'Your Pinterest URL', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['rss-url'] = array(
		'id' => 'rss-url',
		'label'   => __( 'Your RSS feed URL', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['footer-credit'] = array(
		'id' => 'footer-credit',
		'label'   => __( 'Customize Site Footer Text/Link', 'videocloud-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => '&copy; ' . date("o") . ' <a href="' . home_url() .'">' . get_bloginfo('name') . '</a> - Theme by <a href="https://www.happythemes.com" target="_blank">HappyThemes</a>'
	);

	//$options['example-range'] = array(
	//	'id' => 'example-range',
	//	'label'   => __( 'Example Range Input', 'videocloud-pro' ),
	//	'section' => $section,
	//	'type'    => 'range',
	//	'input_attrs' => array(
	//      'min'   => 0,
	//        'max'   => 10,
	//        'step'  => 1,
	//       'style' => 'color: #0a0',
	//	)
	//);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_demo_options' );
