<?php

/**
 * videocloud functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package videocloud
 */

if (!function_exists('videocloud_setup')) :

	function videocloud_setup() {

		load_theme_textdomain('videocloud-pro', get_template_directory() . '/languages');

		// Add default posts and comments RSS feed links to head.
		add_theme_support('automatic-feed-links');

		/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
		add_theme_support('title-tag');

		/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
		add_theme_support('post-thumbnails');

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(array(
			'primary' => esc_html__('Primary Menu', 'videocloud-pro'),
			'footer' => esc_html__('Footer Menu', 'videocloud-pro'),
		));

		/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
		add_theme_support('html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		));

		// Set up the WordPress core custom background feature.
		add_theme_support('custom-background', apply_filters('videocloud_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		)));

		// Add support for Block Styles.
		add_theme_support('wp-block-styles');

		// Add support for editor styles.
		add_theme_support('editor-styles');

		// Enqueue editor styles.
		add_editor_style('style-editor.css');

		// Add theme support for selective refresh for widgets.
		add_theme_support('customize-selective-refresh-widgets');

		// Add support for responsive embeds.
		add_theme_support('responsive-embeds');
	}
endif;
add_action('after_setup_theme', 'videocloud_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function videocloud_content_width() {
	$GLOBALS['content_width'] = apply_filters('videocloud_content_width', 744);
}
add_action('after_setup_theme', 'videocloud_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function videocloud_sidebar_init() {

	register_sidebar(array(
		'name'          => esc_html__('Sidebar', 'videocloud-pro'),
		'id'            => 'sidebar-1',
		'description'   => esc_html__('Add widgets here.', 'videocloud-pro'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	));

	register_sidebar(array(
		'name'          => esc_html__('Homepage Content', 'videocloud-pro'),
		'id'            => 'homepage',
		'description'   => esc_html__('Only put "Home Posts Block" and "Advertisement" widgets here.', 'videocloud-pro'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));


	register_sidebar(array(
		'name'          => esc_html__('Footer Column 1', 'videocloud-pro'),
		'id'            => 'footer-1',
		'description'   => esc_html__('Add widgets here.', 'videocloud-pro'),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));
	register_sidebar(array(
		'name'          => esc_html__('Footer Column 2', 'videocloud-pro'),
		'id'            => 'footer-2',
		'description'   => esc_html__('Add widgets here.', 'videocloud-pro'),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));
	register_sidebar(array(
		'name'          => esc_html__('Footer Column 3', 'videocloud-pro'),
		'id'            => 'footer-3',
		'description'   => esc_html__('Add widgets here.', 'videocloud-pro'),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));
}
add_action('widgets_init', 'videocloud_sidebar_init');

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */

require get_template_directory() . '/admin/customizer-library.php';

require get_template_directory() . '/admin/customizer-options.php';

require get_template_directory() . '/admin/styles.php';

require get_template_directory() . '/admin/mods.php';

require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Woocommerce compatibility
 */
require get_template_directory() . '/inc/woocommerce.php';

/* Demo Content*/
require get_template_directory() . '/demo-content/setup.php';

/**
 * Load plugins.
 */
require get_template_directory() . '/inc/plugins.php';

/**
 * Enqueues scripts and styles.
 */
function videocloud_scripts() {

	// load jquery if it isn't

	wp_enqueue_script('jquery');
	//wp_enqueue_script('jquery', get_template_directory_uri() . '/assets/js/jquery.js', array(), '', true );

	//  Enqueues Javascripts
	wp_enqueue_script('superfish', get_template_directory_uri() . '/assets/js/superfish.js', array(), '20180517', true);
	wp_enqueue_script('modernizr', get_template_directory_uri() . '/assets/js/modernizr.min.js', array(), '20180517', true);
	wp_enqueue_script('html5', get_template_directory_uri() . '/assets/js/html5.js', array(), '20180517', true);
	wp_enqueue_script('sticky', get_template_directory_uri() . '/assets/js/jquery.sticky.js', array(), '20180517', true);
	wp_enqueue_script('flexslider', get_template_directory_uri() . '/assets/js/jquery.flexslider.js', array(), '20180517', true);
	wp_enqueue_script('fitvids', get_template_directory_uri() . '/assets/js/jquery.fitvids.js', array(), '20180517', true);
	wp_enqueue_script('slicknav', get_template_directory_uri() . '/assets/js/jquery.slicknav.min.js', array(), '20180517', true);
	wp_enqueue_script('custom', get_template_directory_uri() . '/assets/js/jquery.custom.js', array(), '20180517', true);

	// Enqueues CSS styles
	$theme_version = wp_get_theme()->get('Version');
	wp_enqueue_style('videocloud-style', get_stylesheet_uri(), array(), $theme_version);
	wp_style_add_data('videocloud-style', 'rtl', 'replace');

	wp_enqueue_style('genericons-style',   get_template_directory_uri() . '/genericons/genericons.css');
	wp_enqueue_style('font-awesome-style',   get_template_directory_uri() . '/assets/css/font-awesome.min.css');

	if (is_woocommerce_activated()) {
		wp_enqueue_style('woocommerce-style',  get_template_directory_uri() . '/woocommerce.css');
	}

	if (get_theme_mod('site-layout', 'choice-1') == 'choice-1') {
		wp_enqueue_style('responsive-style',   get_template_directory_uri() . '/responsive.css', array(), '20180517');
	}

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}
add_action('wp_enqueue_scripts', 'videocloud_scripts');

/**
 * Post Thumbnails.
 */
if (function_exists('add_theme_support')) {
	add_theme_support('post-thumbnails');
	set_post_thumbnail_size(256, 144, true); // default Post Thumbnail dimensions (cropped)
	add_image_size('featured-large-thumb', 367, 206, true);
	add_image_size('post-thumb', 256, 144, true);
	add_image_size('widget-thumb', 130, 73, true);
}

/**
 * Registers custom widgets.
 */
function videocloud_widgets_init() {

	require trailingslashit(get_template_directory()) . 'inc/widgets/widget-popular.php';
	register_widget('videocloud_Popular_Widget');

	require trailingslashit(get_template_directory()) . 'inc/widgets/widget-recent.php';
	register_widget('videocloud_Recent_Widget');

	require trailingslashit(get_template_directory()) . 'inc/widgets/widget-random.php';
	register_widget('videocloud_Random_Widget');

	require trailingslashit(get_template_directory()) . 'inc/widgets/widget-views.php';
	register_widget('videocloud_Views_Widget');

	require trailingslashit(get_template_directory()) . 'inc/widgets/widget-ad.php';
	register_widget('videocloud_Ad_Widget');

	require trailingslashit(get_template_directory()) . 'inc/widgets/widget-newsletter.php';
	register_widget('videocloud_Newsletter_Widget');

	require trailingslashit(get_template_directory()) . 'inc/widgets/widget-home-posts-block.php';
	register_widget('videocloud_Posts_Block_Widget');
}
add_action('widgets_init', 'videocloud_widgets_init');

/* Fix PHP warning */
function _get($str) {
	$val = !empty($_GET[$str]) ? $_GET[$str] : null;
	return $val;
}

if (!function_exists('wp_body_open')) :
	/**
	 * Shim for wp_body_open, ensuring backwards compatibility with versions of WordPress older than 5.2.
	 */
	function wp_body_open() {
		do_action('wp_body_open');
	}
endif;

require trailingslashit(get_template_directory()) . 'inc/post-like.php';
