<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package videocloud
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="HandheldFriendly" content="true">
<link rel="profile" href="http://gmpg.org/xfn/11">
<?php if (get_theme_mod('favicon', '') != null) { ?>
<link rel="icon" type="image/png" href="<?php echo esc_url( get_theme_mod('favicon', '') ); ?>" />
<?php } ?>
<?php wp_head(); ?>

<?php
  
	// Primary Font
	$setting = 'primary-font';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );
	$stack = customizer_library_get_font_stack( $mod );

	if ( $mod != customizer_library_get_default( $setting ) ) {

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.primary'
			),
			'declarations' => array(
				'font-family' => $stack
			)
		) );

	}

	// Secondary Font
	$setting2 = 'secondary-font';
	$mod2 = get_theme_mod( $setting2, customizer_library_get_default( $setting2 ) );
	$stack2 = customizer_library_get_font_stack( $mod2 );

	if ( $mod2 != customizer_library_get_default( $setting2 ) ) {

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.secondary'
			),
			'declarations' => array(
				'font-family' => $stack2
			)
		) );

	}

	// Theme Color
	$primary_color = get_theme_mod('primary-color', '#2da6e9');
	$nav_bg_color = get_theme_mod('nav-bg-color', '#323946');
	$footer_bg_color = get_theme_mod('footer-bg-color', '#4d626e');
?>
<style type="text/css" media="all">
	body,
	input,
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="search"],
	input[type="password"],
	textarea,
	table,
	.sidebar .widget_ad .widget-title,
	.site-footer .widget_ad .widget-title {
		font-family: "<?php echo $mod; ?>", "Helvetica Neue", Helvetica, Arial, sans-serif;
	}
	#primary-menu li a,
	.pagination .page-numbers,
	button,
	.btn,
	input[type="submit"],
	input[type="reset"],
	input[type="button"],
	.comment-form label,
	label,
	h1,h2,h3,h4,h5,h6 {
		font-family: "<?php echo $mod2; ?>", "Helvetica Neue", Helvetica, Arial, sans-serif;
	}
	a,
	a:visited,
	.site-title a:hover,
	.sf-menu ul li li a:hover,
	.sf-menu li.sfHover li a:hover,
	#primary-menu li li a:hover,
	#primary-menu li li.current-menu-item a:hover,	
	.comment-reply-title small a:hover,
	.mobile-menu ul li a:hover,
	.entry-tags .tag-links a:hover,
	.widget_tag_cloud .tagcloud a:hover,
	#primary-bar.light-text .header-cart:hover .cart-data .count,
	.entry-like a.liked,
	.entry-like a:hover,
	#featured-content .entry-meta .entry-like a.liked,
	#featured-content .entry-meta .entry-like a:hover,
	.section-title a:hover {
		color: <?php echo $primary_color; ?>;
	}
	.sf-menu ul,
	button,
	.btn,
	input[type="submit"],
	input[type="reset"],
	input[type="button"],
	button:hover,
	.btn:hover,
	input[type="reset"]:hover,
	input[type="submit"]:hover,
	input[type="button"]:hover,
	.section-heading .section-more a,
	#back-top a:hover span,
	.pagination .page-numbers:hover,
	.pagination .page-numbers.current {
		background-color: <?php echo $primary_color; ?>;
	}
	.flex-control-paging li a:hover,
	.flex-control-paging li a.flex-active,
	.header-cart .widget_shopping_cart p.buttons a.wc-forward:not(.checkout) {
		background-color: #ffbe02;
	}
	.pagination .page-numbers:hover,
	.pagination .page-numbers.current {
		border-bottom-color: <?php echo $primary_color; ?>;
	}
	#primary-menu li:hover,
	.entry-tags .tag-links a:hover,
	.widget_tag_cloud .tagcloud a:hover {
		border-color: <?php echo $primary_color; ?>;
	}	

	#primary-bar {
		background-color: <?php echo $nav_bg_color; ?>;
	}
	.site-footer {
		background-color: <?php echo $footer_bg_color; ?>;
		border-bottom: 5px solid #ffbe02;
	}	
	/* WooCommerce */
	.header-cart:hover .cart-data .count,
	.header-cart .widget_shopping_cart p.buttons a.wc-forward:not(.checkout)	
	.woocommerce #respond input#submit.alt, 
	.woocommerce a.button.alt,
	.woocommerce button.button.alt,
	.woocommerce input.button.alt,
	.woocommerce #respond input#submit,
	.woocommerce a.button,
	.woocommerce button.button, 
	.woocommerce input.button,
	.woocommerce #respond input#submit.alt:hover, 
	.woocommerce a.button.alt:hover,
	.woocommerce button.button.alt:hover,
	.woocommerce input.button.alt:hover,
	.woocommerce #respond input#submit:hover,
	.woocommerce a.button:hover,
	.woocommerce button.button:hover, 
	.woocommerce input.button:hover,
	.woocommerce ul.products li.product .product-actions .button {
		background-color: <?php echo $primary_color; ?>;
	}
	.cart-data .count,	
	.header-cart .widget_shopping_cart .cart_list a,	
	.woocommerce nav.woocommerce-pagination ul li span.current,
	body.woocommerce-checkout .woocommerce-MyAccount-navigation ul li a:hover,
	body.woocommerce-account .woocommerce-MyAccount-navigation ul li a:hover,
	body.woocommerce-cart .woocommerce-MyAccount-navigation ul li a:hover,
	body.woocommerce-checkout .woocommerce-MyAccount-navigation ul li.is-active a,
	body.woocommerce-account .woocommerce-MyAccount-navigation ul li.is-active a,
	body.woocommerce-cart .woocommerce-MyAccount-navigation ul li li.is-active a,
	.woocommerce nav.woocommerce-pagination ul li:hover,
	.woocommerce nav.woocommerce-pagination ul li:hover a,
	.woocommerce nav.woocommerce-pagination ul li:hover span {
		color: <?php echo $primary_color; ?>;
	}	
	.cart-data .count,
	.cart-data .count:after {
		border-color: <?php echo $primary_color; ?>;
	}
</style>

</head>

<body <?php body_class(); ?>>

<div id="page" class="site">

	<header id="masthead" class="site-header clear">

		<div class="site-start">

			<div class="container">

				<div class="site-branding">

					<?php if (get_theme_mod('logo', get_template_directory_uri().'/assets/img/logo.png') != null) { ?>
					
					<div class="logo">
						<span class="helper"></span>
						<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
							<img src="<?php echo get_theme_mod('logo', get_template_directory_uri().'/assets/img/logo.png'); ?>" alt=""/>
						</a>
					</div><!-- .logo -->

					<?php } else { ?>

					<div class="site-title">
						<h1><a href="<?php echo home_url(); ?>"><?php bloginfo('name'); ?></a></h1>
					</div><!-- .site-title -->

					<?php } ?>

				</div><!-- .site-branding -->

				<?php if ( get_theme_mod('header-search-on', true) ) : ?>
					<span class="search-icon">
						<span class="genericon genericon-search"></span>
						<span class="genericon genericon-close"></span>			
					</span>
					<div class="header-search">
						<form id="searchform" method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>">
							<input type="search" name="s" class="search-input" placeholder="<?php esc_html_e('Search', 'videocloud-pro'); ?>" autocomplete="off">
							<button type="submit" class="search-submit"><span class="genericon genericon-search"></span></button>		
						</form>
					</div><!-- .header-search -->

				<?php endif; ?>				

				<?php if ( get_theme_mod('header-social-on', 'true') == true ) : ?>

				<span class="header-social">

					<?php if ( get_theme_mod('facebook-url', '') ) : ?>
						<a class="facebook" href="<?php echo esc_url( get_theme_mod('facebook-url', '') ); ?>"><i class="fa fa-facebook"></i></a>
					<?php endif; ?>

					<?php if ( get_theme_mod('twitter-url', '') ) : ?>
						<a class="twitter" href="<?php echo esc_url( get_theme_mod('twitter-url', '') ); ?>"><i class="fa fa-twitter"></i></a>
					<?php endif; ?>

					<?php if ( get_theme_mod('google-plus-url', '') ) : ?>
						<a class="google-plus" href="<?php echo esc_url( get_theme_mod('google-plus-url', '') ); ?>"><i class="fa fa-google-plus"></i></a>
					<?php endif; ?>
					
					<?php if ( get_theme_mod('youtube-url', '') ) : ?>
						<a class="youtube" href="<?php echo esc_url( get_theme_mod('youtube-url', '') ); ?>"><i class="fa fa-youtube"></i></a>
					<?php endif; ?>

					<?php if ( get_theme_mod('linkedin-url', '') ) : ?>
						<a class="linkedin" href="<?php echo esc_url( get_theme_mod('linkedin-url', '') ); ?>"><i class="fa fa-linkedin"></i></a>
					<?php endif; ?>

					<?php if ( get_theme_mod('pinterest-url', '') ) : ?>
						<a class="pinterest" href="<?php echo esc_url( get_theme_mod('pinterest-url', '') ); ?>"><i class="fa fa-pinterest"></i></a>
					<?php endif; ?>
					
					<?php if ( get_theme_mod('rss-url', '') ) : ?>
						<a class="rss" href="<?php echo esc_url( get_theme_mod('rss-url', '') ); ?>"><i class="fa fa-rss"></i></a>
					<?php endif; ?>					

				</span>

				<?php endif; ?>						

			</div><!-- .container -->

		</div><!-- .site-start -->

		<div id="primary-bar" class="dark-text clear">

			<div class="container">

			<nav id="primary-nav" class="primary-navigation">

				<?php 
					if ( has_nav_menu( 'primary' ) ) {
						wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu', 'menu_class' => 'sf-menu' ) );
					} else {
				?>

					<ul id="primary-menu" class="sf-menu">
						<li><a href="<?php echo home_url(); ?>/wp-admin/nav-menus.php"><?php echo __('Add menu for: Primary Menu', 'videocloud-pro'); ?></a></li>
					</ul><!-- .sf-menu -->

				<?php } ?>

			</nav><!-- #primary-nav -->	

			<div id="slick-mobile-menu"></div>	

			<?php if ( get_theme_mod('header-cart-on', true) ) : ?>

				<?php if ( is_woocommerce_activated() ) { videocloud_header_cart(); } ?>		
			
			<?php endif; ?>		

			</div><!-- .container -->				

		</div><!-- #primary-bar -->			

	</header><!-- #masthead -->

	<div id="content" class="site-content container clear">


	<?php
		get_template_part('template-parts/content', 'featured');
	?>
			
	<div id="primary" class="content-area no-sidebar">

		<div id="main" class="site-main clear">

			<div class="section-heading clear">
			
				<h1 class="section-title">
					<?php
						echo get_theme_mod('recent-heading', __('Full width content', 'videocloud-pro'));
					?>					
				</h1>

			</div><!-- .section-heading -->

			<div id="recent-content" class="content-loop clear">

				<?php

					$temp = $wp_query;
					$wp_query= null;
					$wp_query = new WP_Query( );
					$wp_query->query(
						array( 
							'post__not_in' => get_option( 'sticky_posts' ), 
							'paged' => $paged 
						)
					);

					if ( have_posts() ) :

					while ($wp_query->have_posts()) : $wp_query->the_post();
					
				?>

					<?php 
						global $post;	
						$video_length = get_post_meta($post->ID, 'video_length', true);
					?>
					<div id="post-<?php the_ID(); ?>" <?php post_class('ht_grid_1_4'); ?>>	

						<?php if ( has_post_thumbnail() && ( get_the_post_thumbnail() != null ) ) { ?>
							<a class="thumbnail-link" href="<?php the_permalink(); ?>">
								<div class="thumbnail-wrap">
									<?php 
										the_post_thumbnail('post-thumb'); 
									?>
									<?php if (!empty($video_length)) { ?>
										<span class="video-length"><?php echo $video_length; ?></span>
									<?php } ?>	
									<?php if( (videocloud_has_embed_code() || videocloud_has_embed()) ) {?>
										<div class="video-icon"></div>
									<?php } ?>					
								</div><!-- .thumbnail-wrap -->
							</a>
						<?php } ?>	

						<div class="entry-header">
							<?php if (!is_category()) { ?>
								<span class="entry-category"><?php videocloud_first_category(); ?></span>
							<?php } ?>
							<h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
							<div class="entry-meta">
								<span class="entry-date"><?php videocloud_entry_date(); ?></span>
								<span class="meta-right">
									<span class="entry-like"><?php echo get_simple_likes_button( get_the_ID() ); ?></span>			
									<span class="entry-views"><?php echo videocloud_get_post_views(get_the_ID()); ?></span>
								</span>
							</div><!-- .entry-meta -->
						</div><!-- .entry-header -->

					</div><!-- #post-<?php the_ID(); ?> -->

				<?php
					
					endwhile;

					else :

					get_template_part( 'template-parts/content', 'none' );
					
					endif;
					
				?>

			</div><!-- #recent-content -->
			
		</div><!-- #main -->
		<?php

			the_posts_pagination( array( 'prev_text' => _x( 'Previous', 'previous post', 'videocloud-pro' ) ) );

		?>

		<?php $wp_query = null; $wp_query = $temp;?>

	</div><!-- #primary -->

<?php get_footer(); ?>
